@@ -29,6 +29,7 @@
 #include <ksortablelist.h>
 #include <kxmlguiwindow.h>
 #include <KActionMenu>
+#include <KIcon>
 
 #include <QList>
 #include <QWeakPointer>
@@ -95,9 +96,6 @@ public:
      */
     bool isSplit() const;
 
-    /** Renames the item represented by \a oldUrl to \a newUrl. */
-    void rename(const KUrl& oldUrl, const KUrl& newUrl);
-
     /**
      * Returns the 'Create New...' sub menu which also can be shared
      * with other menus (e. g. a context menu).
@@ -124,6 +122,13 @@ public slots:
      */
     void changeUrl(const KUrl& url);
 
+    /**
+     * The current directory of the Terminal Panel has changed, probably because
+     * the user entered a 'cd' command. This slot calls changeUrl(url) and makes
+     * sure that the panel keeps the keyboard focus.
+     */
+    void slotTerminalDirectoryChanged(const KUrl& url);
+
     /** Stores all settings and quits Dolphin. */
     void quit();
 
@@ -206,13 +211,6 @@ private slots:
     /** Replaces the URL navigator by a search box to find files. */
     void find();
 
-    /**
-     * Is invoked when the "Find" is active and the search location
-     * (From Here/Everywhere) has been changed. Updates the
-     * enabled state of the Search Panel.
-     */
-    void slotSearchLocationChanged();
-
     /**
      * Updates the text of the paste action dependent on
      * the number of items which are in the clipboard.
@@ -349,10 +347,16 @@ private slots:
     void openNewTab();
 
     /**
-     * Opens a new tab showing the URL \a url.
+     * Opens a new tab in the background showing the URL \a url.
      */
     void openNewTab(const KUrl& url);
 
+    /**
+     * Opens a new tab showing the URL \a url and activates
+     * the tab.
+     */
+    void openNewActivatedTab(const KUrl& url);
+
     void activateNextTab();
 
     void activatePrevTab();
@@ -403,13 +407,6 @@ private slots:
      */
     void slotTabMoved(int from, int to);
 
-    /**
-     * Handles a click on a places item: if the middle mouse button is
-     * clicked, a new tab is opened for \a url, otherwise the current
-     * view is replaced by \a url.
-     */
-    void handlePlacesClick(const KUrl& url, Qt::MouseButtons buttons);
-
     /**
      * Is connected to the KTabBar signal testCanDecode() and adjusts
      * the output parameter \a accept.
@@ -440,8 +437,6 @@ private slots:
      */
     void slotWriteStateChanged(bool isFolderWritable);
 
-    void slotSearchModeChanged(bool enabled);
-
     /**
      * Opens the context menu on the current mouse position.
      * @pos           Position in screen coordinates.
@@ -456,11 +451,15 @@ private slots:
                          const KUrl& url,
                          const QList<QAction*>& customActions);
 
-    void updateToolBarMenu();
+    void updateControlMenu();
     void updateToolBar();
-    void slotToolBarSpacerDeleted();
-    void slotToolBarMenuButtonDeleted();
-    void slotToolBarIconSizeChanged(const QSize& iconSize);
+    void slotControlButtonDeleted();
+
+    /**
+     * Is called if a panel emits an error-message and shows
+     * the error-message in the active view-container.
+     */
+    void slotPanelErrorMessage(const QString& error);
 
 private:
     /**
@@ -482,8 +481,8 @@ private:
     void updateViewActions();
     void updateGoActions();
 
-    void createToolBarMenuButton();
-    void deleteToolBarMenuButton();
+    void createControlButton();
+    void deleteControlButton();
 
     /**
      * Adds the action \p action to the menu \p menu in
@@ -585,17 +584,10 @@ private:
     QWeakPointer<DolphinSettingsDialog> m_settingsDialog;
 
     // Members for the toolbar menu that is shown when the menubar is hidden:
-    QWidget* m_toolBarSpacer;
-    QToolButton* m_openToolBarMenuButton;
+    QToolButton* m_controlButton;
     QTimer* m_updateToolBarTimer;
 
-    KJob* m_lastHandleUrlStatJob;
-
-    /**
-     * Set to true, if the filter dock visibility is only temporary set
-     * to true by enabling the search mode.
-     */
-    bool m_searchDockIsTemporaryVisible;
+    KIO::Job* m_lastHandleUrlStatJob;
 };
 
 inline DolphinViewContainer* DolphinMainWindow::activeViewContainer() const
