@@ -411,7 +411,7 @@ QPixmap KStandardItemListWidget::createDragPixmap(const QStyleOptionGraphicsItem
                                                   QWidget* widget)
 {
     QPixmap pixmap = KItemListWidget::createDragPixmap(option, widget);
-    if (m_layout != DetailsLayout || styleOption().extendedSelectionRegion) {
+    if (m_layout != DetailsLayout) {
         return pixmap;
     }
 
@@ -597,6 +597,7 @@ void KStandardItemListWidget::editedRoleChanged(const QByteArray& current, const
     m_roleEditor = new KItemListRoleEditor(parent);
     m_roleEditor->setIndex(index());
     m_roleEditor->setRole(current);
+    m_roleEditor->setFont(styleOption().font);
 
     const QString text = data().value(current).toString();
     m_roleEditor->setPlainText(text);
@@ -605,10 +606,17 @@ void KStandardItemListWidget::editedRoleChanged(const QByteArray& current, const
     m_roleEditor->document()->setDefaultTextOption(textOption);
 
     // Select the text without MIME-type extension
+    // TODO: This is file-item-specific and should be moved
+    // into KFileItemListWidget.
     int selectionLength = text.length();
 
     const QString extension = KMimeType::extractKnownExtension(text);
-    if (!extension.isEmpty()) {
+    if (extension.isEmpty()) {
+        // For an unknown extension just exclude the extension after
+        // the last point. This does not work for multiple extensions like
+        // *.tar.gz but usually this is anyhow a known extension.
+        selectionLength = text.lastIndexOf(QLatin1Char('.'));
+    } else {
         selectionLength -= extension.length() + 1;
     }
 
@@ -684,21 +692,19 @@ void KStandardItemListWidget::slotCutItemsChanged()
 }
 
 void KStandardItemListWidget::slotRoleEditingCanceled(int index,
-                                                  const QByteArray& role,
-                                                  const QVariant& value)
+                                                      const QByteArray& role,
+                                                      const QVariant& value)
 {
-    m_roleEditor->deleteLater();
-    m_roleEditor = 0;
+    closeRoleEditor();
     emit roleEditingCanceled(index, role, value);
     setEditedRole(QByteArray());
 }
 
 void KStandardItemListWidget::slotRoleEditingFinished(int index,
-                                                  const QByteArray& role,
-                                                  const QVariant& value)
+                                                      const QByteArray& role,
+                                                      const QVariant& value)
 {
-    m_roleEditor->deleteLater();
-    m_roleEditor = 0;
+    closeRoleEditor();
     emit roleEditingFinished(index, role, value);
     setEditedRole(QByteArray());
 }
@@ -1240,6 +1246,17 @@ QRectF KStandardItemListWidget::roleEditingRect(const QByteArray& role) const
     return rect;
 }
 
+void KStandardItemListWidget::closeRoleEditor()
+{
+    if (m_roleEditor->hasFocus()) {
+        // If the editing was not ended by a FocusOut event, we have
+        // to transfer the keyboard focus back to the KItemListContainer.
+        scene()->views()[0]->parentWidget()->setFocus();
+    }
+    m_roleEditor->deleteLater();
+    m_roleEditor = 0;
+}
+
 QPixmap KStandardItemListWidget::pixmapForIcon(const QString& name, int size)
 {
     const KIcon icon(name);
